Sutekh Manual

# Manual for Sutekh 0.8

## Contents

1. Introduction
2. Important Concepts
3. Main Window
   1. File
      1. Backup
      2. Import CSV file
      3. Import ARDB or ELDB file
      4. Import card sets from zip file
   2. Pane Actions
   3. Rulebook
   4. Keyboard Shortcuts
   5. Minimizing Panes
   6. Refreshing the White Wolf Card List
4. White Wolf Card List
   1. Actions
   2. Edit
   3. Filter
   4. Analyze
5. Card Text
6. Card Image
7. Card Set List
   1. Actions
   2. Edit
   3. Filter
8. Card Sets
   1. Actions
   2. Edit
   3. Filter
   4. Analyze
   5. Keyboard Shortcuts
9. Other dialogs
   1. Card Lookup Dialog
   2. Search Dialog
10. Filters
    1. Card Filters
    2. Card Set Filters
    3. Combining Basic Filters
    4. String filters
    5. List filters
11. Analysis Tools
    1. Cluster Cards
    2. Clan Discipline Stats
    3. Expansion Stats
    4. Compare with another Card Set
    5. Analyze Deck
    6. Test Card Set Independence
    7. Simulate Opening Hand
    8. Card draw probabilities
12. Profiles
    1. Edit Profile
    2. Managing Profiles
    3. White Wolf Card List Profile Options
       1. Card Grouping
       2. Extra Columns — card sets
    4. Card Set Profile Options
       1. The Different Profiles
    5. CardSet List Profile Options
       1. Extra Columns — card set list

## Introduction

If you are new to Sutekh, try reading The Sutekh Tutorial.

## Important Concepts

Sutekh is concerned with two different types of objects: Cards and Card Sets.

Cards are the individual cards as described by the official White Wolf card list. Sutekh describes all the relevant properties of each card, such as the clan and discipline requirements, the cost, and the latest card text.

You can set the expansion to which each specific card belongs. This allows you to distinguish between multiple copies of the same card from different expansions. If the expansion is not set, Sutekh notes this as Unknown Expansion in the card set view.

Card Sets are collections of cards, and describe each card and the number of copies of that card in the collection. Card sets can be related in a parent-child hierarchy. In a typical setup, there is a single card set for the main card collection (usually the My Collection card set); and other card sets, which represent constructed decks, are children of this card set — but many other arrangements are possible.

## Main Window

You can split the main Sutekh window into a number of different panes.

The following panes are supported:

- The White Wolf card list
- The Card Set List
- Card Text
- Card Image
- Card Set panes

Each pane may have an associated menu for actions specific to that pane. The main window has a menu for global actions.

You can easily rearrange panes. You can swap two panes by dragging one onto the other. For most panes, this can be done from any section that won’t start another drag operation (such as dragging cards), but, so that it is possible to easily select and copy card text, the card text pane can only be dragged by using the pane title.

### File

The file menu has the following options.

- Backup: Save or restore backups of the database, discussed further in the Backup section.
- Import Card Set: Import a card set from a existing file. The following file types are supported:
  - Load Card Set from File: Load a card set saved in Sutekh’s XML file format.
  - Import CSV File: Import a card set from a comma-separated value file, as produced by a spreadsheet. You can select the columns for card set, number and expansion.
  - Import ARDB or ELDB Card Set: Import a file saved by either ARDB or FELDB. You may specify the correct type of file as well as the file name.
  - Import Card Sets from zip file: Select card sets from a zip file to import.
- Data Downloads: This submenu allows you to update data from the various external sources Sutekh uses.
  - Import new White Wolf Card List and rulings: Update the database with a new cardlist and/or rulings file. You can either specify local files, or opt to download them from the appropriate websites directly. Sutekh may encounter problems when updating the card list after a new expansion has been published — this is discussed further in the section Refreshing the White Wolf Card List.
  - Download VTES icons: Attempt to download the icons from the White Wolf website.
  - Download starter decks: Download and import a list of the White Wolf preconstructed decks from the sutekh wiki. The zip file also includes the details of the storyline and demo decks released by WW, but these can be excluded using the checkboxes. If you have not imported the details of these extra cards (see Refreshing the White Wolf Card List), these will be greyed out and automaticaly excluded.
  - Download or Configure Card Images: Download images of the cards for the Card Images pane, or use an existing zip file or directory of images.
  - Download Rulebook Files: Download the various files for the Rulebook menu.
- Preferences: Manage various preferences.
  - Use “path of …, the” name display: If selected, card names prefixed with “The”, “An” or “A” are displayed and sorted with the prefix at the end.
  - Save Pane Set on Exit: Save the pane configuration when Sutekh exits.
  - Save Exact Pane Positions: Save the exact pane positions on exit.
  - Save Window Size: Save the window size on exit.
  - Show Starter Information: If the starter decks have been downloaded into the database, this will add a list the starter decks a card has been published in to the Card Text pane when the card is selected.
  - Export to HTML preferences: Set the destination for the links created in the exported HTML files.
- Manage Profiles: Bring up the profile management dialog to edit or delete the various pane profiles
- Save Current Pane Set: Save the current configuration of the panes.
- Restore saved configuration: Restore the panes to the saved configuration.
- Quit: Exit Sutekh.

If Sutekh encounters an unknown card when importing card sets, it will prompt you to identify it using the Card Lookup Dialog.

#### Backup

This allows you either to save or to restore a full backup of the current database. The backup is saved as a zip file, and is independent of the database back-end which Sutekh uses. Consequently, the backup can also be used to transfer the complete state between different databases.

There are two options offered:

- Save a Full Backup: Save the current state (card sets and their contents) to the specified zip file.
- Restore a Full Backup: Import all the card sets from the specified zip file. Note that restoring a backup will replace anything currently in the database with the contents of the backup.

You can save a backup at any time. Sutekh will ask you whether you would like to save a backup when you initiate certain actions, such as updating the White Wolf card list.

#### Import CSV file

This allows you to import card sets stored as a comma-separated file, a format commonly produced by spreadsheets. The file must contain a column with card names and a column with card counts, and can optionally contain a column with expansions. When you importing the file, you must specify the mapping between the columns and their contents.

If Sutekh cannot correctly interpret a name or expansion, it will prompt you to resolve the situation using the Card Lookup Dialog.

#### Import ARDB or ELDB file

This allows you to import files produced by ARDB, JOL, Lackey CCG or FELDB. While Sutekh will attempt to identify the file format automatically, this isn’t always reliable, so you have the option of specifying the format manually.

For some types of file, such as ARDB inventories, you will also need to specify a card set name for the imported file.

If the name of the card set clashes with an existing name, you will be asked to rename the imported card set or cancel the import.

If no cards are found in the card set, the card set will not be created.

#### Import card sets from zip file

This option allows you to select some or all of the Sutekh Card Sets included in a zip file (such as those produced by backups) and import them into the card set. Unlike restoring a backup, this does not replace any existing card sets automatically.

After selecting the zip file, you will be asked to select the card sets to import from the list of card sets in the zip file. If any of the card sets share the same name as an existing card set, you will be asked either to rename the card set, or skip importing that card set.

If a card set to be imported has a parent card set, and that set cannot be found, the card set will be imported with no parent set.

### Pane Actions

This menu allows you to manage the panes in Sutekh. The Pane Actions menu has the following options:

- Equalize pane sizes: Rearrange the panes so that each pane has the same width, and panes which are split vertically all have the same height. Pane equalizing may also be triggered using the <Ctrl>-p shortcut.
- Split current pane horizontally: Split the currently active pane into the currently active pane and a new pane to the immediate right of the active pane. The two panes will be the same height as, and half the width of the pane being split.
- Split current pane vertically: Split the currently active pane into the currently active pane and a new pane below the active pane. The two panes will be the same width as, and half the height of the pane being split. It is not possible to split panes vertically multiple times.
- Add New Pane: Add a new pane of the chosen type to the far right of the main window.
- Replace Pane: Replace the currently active pane with another. The available options will be presented in a submenu.
- Close Pane: Close the currently active pane.

### Rulebook

Once you have downloaded the rulebook files, you can open them in a web browser using the Rulebook menu.

The available files are copies of the rulebook, the rules reference, the V:EKN tournament rules, imbued rules and card rulings from the White Wolf site and the VTES and Imbued FAQ’s hosted on www.thelasombra.com.

To download the files, or update your existing copies, use the _Download Rulebook Files_ item in the Data Downloads submenu.

### Keyboard Shortcuts

The following shortcuts are useful for most panes:

You can cycle between different panes using the <Tab> key.

You can close the currently active pane using the <Ctrl>-W shortcut.

In panes which support filtering, you can activate the filter editing dialog using <Ctrl>-S (for “*S*pecify filter”), and toggle the current filter on and off using <Ctrl>-T.

The <Ctrl>—+ and <Ctrl>—- shortcuts allow you to expand fully or collapse completely the entire tree displayed in a pane.

### Minimizing Panes

Double-clicking on a pane title will minimize the pane to a toolbar below the main menu. The toolbar is hidden if no frames are currently minimized. Clicking on a pane listed on the toolbar will unminimize it and place to the right of current set of open panes.

### Refreshing the White Wolf Card List

This allows Sutekh to update the card list to account for new cards, such as promos.

Sutekh parses the card list published on the V:EKN site for information about the cards. When new expansions are published, Sutekh may require an update to interpret major changes to the cardlist, such as new clans or card types. If the expansion does not introduce any significant changes, Sutekh may be able to import the new card list correctly, but may be unable to interpret the new expansion name. If this happens, Sutekh should continue working, but you may need to specify the correct mapping for the expansion when updating the database during your next upgrade.

The Storyline Card File provides information not included in the official V:EKN card list. This includes information about the various special storyline cards that have been printed, and also details various special expansions, such as those for the demonstration decks, that have been released.

## White Wolf Card List

This pane contains a list of all the cards imported from the official White Wolf card list.

### Actions

The Actions menu allows the following actions:

- Show card expansions: Toggle display of the card expansions in which each card was printed below the card name in the list.
- Show icons for the grouping: Toggle whether icons are shown for the top level grouping (when available).
- Expand All: Expand all the items in the tree.
- Collapse All: Collapse the tree as far as possible.

### Edit

- Copy selection: Copy the currently selected set of cards into the buffer. You can paste this into an editable card set to add the selected cards to it.
- Search: Open up a search dialog which will search the list for a card with a name starting with the typed text. The search dialog can also be opened by either using the <Ctrl>-F shortcut, or by simply starting to type in the list view.

### Filter

The filter menu has three options:

- Specify Filter: Specify the filter to apply to the card list. See the Card Filters section.
- Apply Filter: Toggle whether the filter is currently applied to the list.
- Create Card Set From Filter: Create a new card set containing the results of the current filter. The new card set will be opened automatically and will be set editable.

### Analyze

The following analysis options are available for White Wolf Card List:

- Clan Discipline Stats
- Expansion Stats
- Cluster Cards

## Card Text

The Card Text Pane displays the text on the card, and any rulings that apply to the card.

This will also list other relevant information about the card, such as the card cost, the card type, the disciplines or virtues associated with the card, the clans and creeds associated with the card, vampire titles, sects and groups, capacity and the expansions in which the card was printed.

## Card Images

If the card images have been installed, this pane will display the appropriate card image for each pane. By default, all images are resized to fit the pane. You can change this setting by right-clicking on the image.

The following options are available:

- Fit images to the pane: All images are resized to fit the pane.
- Show images at fixed size: All images are resized to 225×300 pixels.
- Show images at original size: All images are shown at the original size of the scan.

If there are multiple images for the given card from the different expansions, Sutekh will attempt to display the correct expansion for the selected card. You can cycle through the available expansions either by left-clicking on the image, or by selecting the Show next expansion image and Show previous expansion image options after right-clicking on the frame.

## Card Set List

This pane lists all the card sets which have been defined. The card sets are arranged so that child card sets are listed below their parents.

You can open a card set either by double-clicking on its name, or by dragging the name to an existing pane.

You can change the parent of a card set by dragging the card set name onto the new parent’s name.

You can mark sets either as in use or not in use. This is intended to help you track which cards are currently available for you to use in new card sets.

It’s possible to open multiple copies of a given card set.

### Actions

The following actions are available:

- Create New Card Set: Create a new card set. The new card set will be opened in a new pane, and will be set to be editable.
- Edit Card Set Properties: Change the card set name, author and description, change the parent of the card set, or add annotations to the card set.
- Mark/Unmark Card Set as In Use: Toggle whether the card set is in use or not in use.
- Delete Card Set: Delete the currently selected card set.
- Expand All: Expand all the items in the tree.
- Collapse All: Collapse the tree as far as possible.

### Edit

- Search: Open up a search dialog which will search the list for a card set with a name starting with the typed text. The search dialog can also be opened by either using the <Ctrl>-F shortcut, or by simply starting to type in the list view.
- Edit Profiles: Open up a edit profile dialog for adding or changing profiles for the card set list.
- CardSet List Profile: Allows you to select between the available profiles for the card set list.

### Filter

The filter menu has two options:

- Specify Filter: Specify the filter to apply to the card set list. See the Card Set Filters section.
- Apply Filter: Toggle whether the filter is currently applied to the list.

## Card Sets

This pane lists the contents of a specific card set.

The display has several columns. A column for the number of cards, a column for the number of cards in the parent card set (the parent count column) and a column for the card name. Extra columns can be enabled as well.

By default, the card set is sorted on the card name, but it can be sorted by any of the columns.

The parent card column is hidden, and cannot be enabled, if the card set has no parent. By default, the parent count column is hidden if the parent card set is empty, but it can be shown.

### Actions

The Actions menu allows the following actions:

- Edit Card Set Properties: Change the card set name, author and description, change the parent of the card set, or add annotations to the card set.
- Save Card Set to File: Save the card set to Sutekh’s XML format.
- Export Card Set: Export the card set to other file formats. The currently supported options are:
  - CSV: A comma-separated format suitable for importing into spreadsheets
  - FELDB file: A file that can be imported into the FELDB card manager
  - ARDB XML: A file that can be imported into the ARDB card manager
  - HTML: A nice HTML file, similar to that produced by ARDB
  - ARDB Text: A text file, similar to that produced by ARDB
  - JOL: A text file that can be pasted into the Jyhad Online deck builder
  - Lackey CCG: A text file that can be imported into the Lackey CCG client
- Expand All: Expand all the items in the tree.
- Collapse All: Collapse the tree as far as possible.
- Delete Card Set: Delete the card set from the database.
- Print Card Set: Print the card set.

### Edit

This menu has the following options:

- Card Set is Editable: Toggle whether the card set is editable. When the card set is not editable, you may not add cards to the set or delete cards from the set directly.
- Copy selection: Copy the currently selected set of cards into the buffer.You can paste this into an editable card set to add the selected cards to it.
- Paste: Paste the previously copied selection into the current card set. This option is only available when the card set is editable.
- Delete selection: Delete the selected cards from the card set. This is only possible when the card set is editable. The deleted selection is not placed in the buffer.
- Search: Open up a search dialog which will search the list for a card with a name starting with the typed text. The search dialog can also be opened by either using the <Ctrl>-F shortcut, or by simply starting to type in the list view.
- Set selected cards to a single expansion: This searches for expansions which are common to all the selected cards, and allows you to choose one of these. The physical expansion for all the selected cards is set to this choice.
- Take a snapshot of this card set: This creates a copy of the current state of the card set, and appends the current date and time to the name. The newly created card set is a child of the current card set.

If the card set is not editable, you cannot make changes to its contents directly. It is still possible for you to change the card set contents by editing the parent card set when the Display Mode -> Show Child Card Sets option is active.

### Filter

The filter menu has three options:

- Specify Filter: Specify the filter to apply to the card list. See the Card Filters section.
- Apply Filter: Toggle whether the filter is currently applied to the list.
- Create Card Set From Filter: Create a new card set containing the results of the current filter. The new card set will be opened automatically and will be set editable.

When editing a card set, the display is always updated according to the active filter (i.e. if the filter is being applied). This does mean that, when adding cards to a card set when a filter is active, not all the new cards may be displayed, and, when using a filter that includes the card count, cards may appear and disappear due to the changing counts.

Since complex filters may be expensive to evaluate, editing card sets with a filter active will be slow in some cases.

### Analyze

The following analysis options are available for card sets:

- Analyze Deck
- Card draw probabilities
- Cluster Cards
- Compare with another Card Set
- Simulate Opening Hand
- Test Card Set Independence

### Keyboard Shortcuts

For card sets, the following additional keyboard shortcuts exist:

You can toggle the editable state of the card set using <Ctrl>-E.

You can copy the current selection to the clipboard using <Ctrl>-C.

If the card set is editable, you can delete the current selection using <Del> or paste a copied selection into the card set using <Ctrl>-V.

In an editable card set, you can set the count for all the cards in a selection to a number from one to ten by typing the number directly. You can increment and decrement the count for all the cards in a selection using + and -. If the card set is not editable, these keys have no effect.

## Other Dialogs

### Card Lookup Dialog

For various reasons, Sutekh may fail to identify a card correctly when importing a card set. Names vary (“Spirit’s Touch”, “The Spirit’s Touch”), special characters can be missing, etc.. When this happens, Sutekh will prompt you for the correct card.

The card lookup window displays two lists: the list of all White Wolf cards and the list of unknown cards. Below the unknown card list are options to specify a filter, to apply or unapply the filter, to show or hide cards not legal for tournament play or to search the card list.

The unknown card list has two columns — the name of the unknown card and the currently selected replacement from the White Wolf card list — and three buttons. Use the first button to replace the card with the currently selected card, the second button to mark the card as ignored, and the last to view a list of reasonable options (Sutekh finds these by applying a filter based on the unknown card name).

Once you have selected replacements for all unknown cards (or chosen to ignore them), use the OK button to create the card set.

If you choose to cancel, the entire import will be aborted and no card set will be created.

If Sutekh cannot identify an expansion in the file, it will prompt you for the correct replacement. If Sutekh finds an impossible card and expansion combination, it will prompt you to resolve the situation using the card lookup dialog — but you will have the opportunity to select both the card and the expansion.

### Search Dialog

The search dialog can be used to find specific cards or card sets quickly.

In the main window, it can be popped up by using the menu item, the <Ctrl>-F shortcut, or by starting to type in the window directly.

In the card lookup window, it can be popped up by using the search button, the <Ctrl>-Fshortcut, or by starting to type.

The dialog can be hidden by either pressing the Escape key, the Enter key, or by clicking outside the search dialog. Note that, to prevent unexpected side-effects, while the search dialog is shown, clicking will only hide the dialog and not effect any else.

The search looks to match names starting with the typed text. When multiple cards match, you can easily move between them by using the up or down keys while the search dialog is visible.

## Filters

Filtering is one of the most common activities in Sutekh. You can construct complex queries by combining various basic filters.

The Filter dialog will display the last used filter for the given pane. You can clear or modify this filter using the Clear Filter button.

You can save complex filters for later reuse using the Save button, and recall them using the Load button. When modifying a filter, you can revert to the saved version using the Revert Filter button. A saved filter will include all values currently set for the filter.

### The Filter Dialog

The filter dialog is laid out with 3 panes. The central pane shows the current filter, with any values that have been set so far.

The left hand pane lists all the different possible filter types. Individual filter elements can be dragged from this into the central filter pane, and the filter elements can be re-arranged within the central pane as well. This is mostly useful when using multiple filter groups (see Combining Basic Filters).

When a filter element is selected, the right hand pane allows for the values for that filter element to be selected. This also provides buttons to delete filter elements or values, negate the meaning of the filter element and to temporarily disable filter elements.Disabled filter elements are not used in the filter, but the values set for the element are preserved. These options are also available from a Right-Click context menu.

The buttons also have associated keyboard accelerators. Pressing <Del> will delete the current filter element, <Ctrl>-<space> will disable the current filter element and <Alt>-<space> will negate the filter element. <Tab> can be used to move between the different elements in the filter dialog. It’s possible to switch between the two panes (and the filter list elements in a pane) using <Alt>-<left> and <Alt>-<right>.

Filter values can be dragged from the right-hand pane into any filter of the same type. Filter values can also be dragged between filters of the same type.

The currently selected set of values in the right-hand pane can be pasted into the currently selected filter element using <Ctrl>-<Enter>.

Filters and filter values can be removed from the filter by using the buttons, using the context menu, or by dragging filter elements from the left hand pane to the right hand pane.

### Card Filters

These filters apply either to the White Wolf card list or a card set. The following basic filters are supported:

- Card Type: Filter on the type of card. You must specify a list of card types. A card matches if any one of its types matches any type in the list.
- Cost Type: Filter on the type of cost which must be paid for the card. You must specify a list of cost types. The filter ignores the numerical cost, and considers only the cost type. If you wish to filter on a specific cost and cost type, you must combine this filter with the Cost filter.Presently, the recognised types of cost are pool, blood and conviction, and this filter matches only library cards. Vampire capacity and ally/retainer life are not considered to be cost types.
- Clan: Filter on the clan(s) listed on the card. You must specify alist of clans. A card matches if any clan listed on the card matches any clan in the list.
- Discipline: Filter on the discipline(s) listed on the card. You must specify a list of disciplines. A card matches if any discipline listed on the card matches any discipline in the list. This filter ignores discipline levels.
- Group: Filter on the group of a crypt card. You must specify a list of groups. A card matches if its group matches any group in the list.
- Capacity: Filter on the capacity listed on the card. You must specify a list of capacities. A card matches if its capacity matches any capacity in the list.
- Cost: Filter on the cost which must be paid for the card. You must specify a list of costs. A card matches if its cost matches any cost in the list numerically. This filter ignores the cost type, and considers only the numerical cost. If you wish to filter on a specific cost and cost type, you must combine this filter with the Cost Type filter (see Combining Basic Filters). Note that cards without a cost are considered not to have a cost type either, so filtering for a cost of 0 and a cost type will fail to match any cards.
- Life: Filter on the life value of a card. You must specify a list of life values. A card matches if the life value listed on the card matches any life value in the list. This filter matches crypt cards which have a life value (such as the Imbued), and match library cards which have a life value (other allies, and retainers). For allies and retainers this matches only the base life if the life varies with discipline level.
- Creed: Filter on the creed(s) listed on the card. You must specify a list of creeds. A card matches if any creed listed on the card matches any creed in the list.
- Virtue: Filter on the virtue(s) listed on the card. You must specify a list of virtues. A card matches if any virtue listed on the card matches any virtue in the list.
- Card Text: Filter on the text of the card. You must specify a string. A card matches if the string appears in the card text. This filter ignores the card name. You can use % and _ as wildcard characters.
- Card Name: Filter on the name of the card. You must specify a string. A card matches if the string appears in the card name. You can use % and _ as wildcard characters.
- Sect: Filter on the sect(s) listed on the card. You must specify a list of sects. A card matches if any sect listed on the card matches any sect in the list.
- Title: Filter on the vampire title(s) listed on the card. You must specify a list of titles. A card matches if any title listed on the card matches any title in the list.
- Keyword: Filter on keywords associated with the card. You must specify a list of keywords. A card matches if any keyword connected with the card matches any keyword in the list.
- Artist: Filter on artists who have created art for the card. You must specify a list of artists. A card matches if any artist in the list has drawn art for any printing of the card.
- Expansion with Rarity: Filter on the expansions and rarities in which the card has been printed. You must specify a list of expansion and rarity combinations. A card matches if it has been printed in one of the given expansion and rarity combinations. This filter considers all the expansions and rarities in which a card has ever been printed, and ignores the specific physical expansion information on the card. If you want to filter on a card’s physical expansion information, use the Physical Expansion filter.
- Discipline with Level: Filter on the discipline(s) listed on the card and their levels. You must specify a list of discipline and level combinations. A crypt card matches if any discipline listed on the card, and its listed level, match any combination in the list. This filter is intended to be used to find vampires — presently, all library cards which have a discipline requirement have that discipline associated with them at the superior level. This filter treats different levels of the same discipline as different and unrelated disciplines, so a list which contains only the inferior version of a discipline will not match a card which has the superior version of that discipline.
- Physical Expansion: Filter on a card’s expansion information. You must specify a list of expansions. A card matches if its listed expansion matches any expansion in the list. This is different from the _Expansion_with_Rarity_ filter, since it ignores rarities, and matches the specific physical expansion of the card, not the list of expansions in which the card has been printed.
- Card Sets: You must specify a list of card sets. A card matches if it belongs to at least one set in the list. This filter matches on name and expansion, so the filter will return as many copies of the card exist in this set, not the same number as in the listed sets.
- In Card Sets In Use: A card matches if it belongs to a card set which is marked as In Use and is a child of the given card set. Like the Card Sets filter, this matches solely on the card name and expansion, and the numbers are those for this card set, not the number in the in use children.
- Card Count: Filter on card count within the current card set or a different card set. You must specify a list of card counts, and a list of card sets.A card matches if it belongs to one of the specified sets, and has a count within that set equal to any count in the list.
- Card Function: Filter on common card functions. You must specify a list of card functions. A card matches if it satisfies at least one function in the list.
- Filter Group: Add an additional filter group to the filter. See Combining Basic Filters

You can also use these filters in the Card Lookup Dialog during a card set import — they can assist you in finding matches for unknown cards.

Currently, the only way to filter on the properties of a merged vampire, such as different discipline levels, is to filter on the card text.

### Card Set Filters

These filters apply to the card set list. The following basic filters are supported.

- Card Set Name: Filter on the card set name. You must specify a string. A card set matches if the string appears in the card set’s name. You can use % and _ as wildcard characters.
- Card Set Description: Filter on the card set description. You must specify a string. A card set matches if the string appears in the card set’s description. You can use % and _ as wildcard characters.
- Card Set Author: Filter on the card set author. You must specify a string. A card set matches if the string appears in the card set’s author name. You can use % and _ as wildcard characters.
- Card Set Annotations: Filter on the card set annotations. You must specify a string. A card set matches if the string appears in the card set’s annotations. You can use % and _ as wildcard characters.
- Parent Card Set: You must specify a list of card sets. A card set matches if any card set in the list is its parent set.
- Card Set Marked as in Use: A card set matches if it is marked as In Use.
- Filter Group: Add an additional filter group to the filter. See Combining Basic Filters

When Sutekh displays card sets which match a filter, all the direct ancestors of those sets are also displayed even if they do not match the filter themselves, so that the matching sets can be shown in their correct position in the hierarchy.

### Combining Basic Filters

You can combine filters by using filter groups to group the basic filters together.

A Filter group can be set to any of the following options.

- All of: This filter matches only if every filter in the group matches.
- Any of: This filter matches if at least one of the filters in the group matches.
- Not all of: This filter matches if at least one of the filters in the group doesn’t match.
- Not any of: This filter matches only if none of the filters in the group match.

Each filter group can also contain further filters groups.You can thus construct complex queries by nesting multiple filter groups.

### String filters

Several filters check a string which you specify against a particular text property. They will match if the given string is a substring of the property.

String filters are case-insensitive: for example, if you use the Card Name filter, the string the will match both Weigh the Heart and Yuri, The Talon.

String filters can also use two different wildcard characters:

_ will match any single character. Thus a_c will match both abc and aec, but not abdc or abd. _ will never match the empty string, so Th_e will not match The, but will match Thee

% will match any sequence of characters. So a%c will match any of abc, aec or abdegfthc, but not abdefg. % will also match the empty string, so Th%e will match both The and Three.

Wildcards can be used multiple times in the same filter string. So a_b%e will match any of acbde, aebe or aebfe.

### List filters

Several filters check a list of possible options which you specify against some property. They will match if the value of the property matches any item in the given list.

Thus, if you use the Clan filter and specify both Tremere and Toreador, it will match cards which list either of these clans.

## Analysis Tools

### Cluster Cards

The clustering tool attempts to group cards from a card list into sets (clusters) of cards with similar properties. It is designed to allow you to explore subsets of your cards, and perhaps to look for groups of cards which might provide starting points for deck construction. The clustering tool is currently quite slow, so be patient when waiting for large card lists to be grouped (it will finish eventually).

When you open the clustering tool, you will be presented with three tabs: Select Columns, Settings and Results.

The Select Columns tab is where you select the properties for the tool to consider when grouping the cards. Properties are organised into categories for ease of selection. If you are unsure which properties to select, start by selecting the disciplines and clans which you find the most interesting.

In the Settings tab, you can tweak the clustering algorithm parameters. The tool implements K-means clustering using K-means++ to determine the initial cluster centers, followed by Lloyd’s method of iteratively refining the clusters. Three parameters can be set:

- Number of iterations: Number of Lloyd refinement steps to perform. Setting more steps makes the clustering take longer, but setting fewer steps may result in a less optimal grouping. Ten steps should be sufficient for most cases.
- Number of clusters: By default, the tool creates one cluster per 80 cards (this being the size of a deck), but the number of clusters may also be set manually.
- Distance measure: Two distance metrics are currently supported. The Euclidean distance setting clusters using the usual N-dimensional vector space metric. The Sutekh distance metric modifies the Euclidean metric to make property values of -1 (used internally by Sutekh to mark costs of X and the ANY crypt group) close to all others and values of zero slightly further away than usual. If in doubt, leave the metric set to the Sutekh distance.

Once the property columns have been selected and the parameters set, use the Execute button to begin the clustering. When clustering is complete, the Results tab will be populated.

The results are presented as a table. Each row corresponds to a cluster of cards. The first column contains checkboxes. Use these to select which clusters to use to create card sets, then click the Make Cards Sets from Selected Clusters button at the bottom of the results. The second column contains the cluster number, which enables you to determine which clusters correspond to the created card sets. The third column shows how many cards are present in each cluster, and the last lists the property values of the cluster center (property values of zero are omitted).

### Clan Discipline Stats

This shows an analysis of all the different clans in the White Wolf card list. For each clan, it displays the total number of vampires in the clan, the sum of the vampires’ capacities, and the most common disciplines. It also shows the score for the disciplines, and various stats about how the disciplines are distributed.

You can expand the tree view to show the details for each legal grouping combination.

The score is intended to give you some indication of how common disciplines are within the clan. Vampires without a discipline score 0 for that discipline, vampires with the inferior discipline score 1 and vampires with the superior discipline score 2.

Note that this will only include cards not legal for tournament play (such as banned cards or storyline only cards) if the current profile for the white wolf card list shows those cards.

### Expansion Stats

This lists some statistics about the different expansions and rarities.

For each expansion, this lists the number of cards of each rarity. It also notes which cards are found only in the preconstructed decks for that expansion if needed. For each rarity, the individual cards are list, grouped according to the current grouping of the white wolf card list.

Note that this will only include cards not legal for tournament play (such as banned cards or storyline only cards) if the current profile for the white wolf card list shows those cards.

### Compare with another Card Set

This tool compares the current card set with a different card set. It displays which cards are common to both card sets, and lists the unique cards in each card set.

By default, the tool considers the expansions of cards, and considers all cards with the same name with different expansions as different.You can change this behaviour using the Ignore Expansions checkbox when selecting a card set for comparison. If selected, all cards of with the same name are considered the same, regardless of expansion.

The display of the results uses the same grouping as the card set.

You can create card sets from each list of results using the 'Create Card Set from this list’ button.

### Analyze Deck

This tool examines a card set and displays various statistics about it which are intended to give you some indication of how the card set will operate as a deck.

It displays several tabs, each of which summarises different aspects of the card set. The first tab summarises some basic information about the entire set. The second tab implements Legbiter’s Happy Family analysis for the card set. The remaining tabs consider specific card types.

The happy family implementation allows you either to select the number of disciplines to use, or to select the disciplines to consider manually.

### Test Card Set Independence

This tool tests the current card set against other card sets with the same parent, and considers whether there are enough cards in the parent card set to simultaneously construct all the selected sets. Multiple decks can be selected from the list of card sets.

You can test the current card set against all sets with the same parent which are marked as In Use by checking the Test against all card sets marked as in use checkbox when selecting decks for comparison. This checkbox overrides any selected entries in the list.

By default the independence test is strict and checks whether the parent set contains enough cards to build all the selected child sets with exactly the card expansions specified. A less strict check which ignores expansions may be selected by checking Ignore card expansions.

The first tab of the results displays the full list of cards of which there is a shortage in the parent card set. For each selected set which includes any of these cards, the list of cards relevant to that set is shown in a separate tab.

### Simulate Opening Hand

This tool treats the card set as a completed deck, and displays the expected distribution of cards in the opening hand and crypt. It is intended to give you some idea of how the deck will work in practice. In addition, you can generate example opening hands and crypts by clicking the Draw sample hand button.

### Card draw probabilities

This tool displays the probabilities of drawing the selected cards from the library or the crypt. Unlike the simulate opening hand tool, this displays results for longer sequences of card draws.

The first row of the table shows the probabilities of drawing a single card in the selected list. Sub-rows show the individual probabilities for each possible combination of selected cards. The second row shows the probabilities of drawing all possible combinations of two selected cards, etc..

Each probability cell in the table displays two values: the probability of drawing at least that combination of cards, and the probability of drawing exactly that combination of cards (shown in brackets).

The tool has the following settings:

- columns in table: Set the number of draws shown in the table. You must specify a number from one to eight (the default is eight). The first column shows the probabilities of drawing the given cards in your opening hand or crypt draw. Subsequent columns show the total probabilities of drawing the cards after you have drawn the number of extra cards shown in the column header.
- step between columns: Set the number of cards drawn between columns. You must specify a number from one to ten (the default is one).
- cards of interest: Set the number of rows in the table. You must specify a number from one to the total number of cards selected.

The selected changes are only applied when you press the the recalculate table button.

## Profiles

### Editing Profiles

The Edit Profile dialog is an interface for creating new profiles of the appropriate type, or to adjust the settings of the profile.

New Profiles can be created by selecting the New Profile option from the drop down list. Otherwise, the profile to be edited can be selected. Profiles can be renamed by editing the name field.

Changes are only applied if the Save and Close option is chosen. The changes are applied to all panes used the edited profile.Cancel discards all changes made.

### Managing Profiles

The Profile Management dialog is found under the File menu.

The dialog has tabs for each profile type. You can choose to either edit the selected dialog, in which case the Edit Profile dialog is opened with the selected profile, or delete the selected profile.

If a profile is deleted, any panes or card sets using that profile change to the default profile.

### White Wolf Card List Profile Options

You can set the following options for the white wolf card list in the profile:

- Column mode: This controls how information in the extra columns is displayed. You can choose to only show test, only show icons (if applicable) or to show both.
- Extra columns: Select which extra columns of data are shown. See the Extra Columns section for more details.
- Extra levels: Controls whether the card expansions are listed.
- Group by: Controls how the cards are grouped together. See the Card Grouping section for more details.
- Hide cards not legal for tournament play: Controls whether cards flagged as not legal for tournament play (i.e. banned or storyline only cards) are shown in the list.
- White Wolf Card List Count Mode: By default, the White Wolf card list doesn’t show a count for cards. This option allows you to choose between the default Don’t show card counts mode, Show counts for each distinct card and Show counts for each expansion. In Show counts for each distinct card, each distinct card has a count of 1, but expansions aren’t counted. This can be useful for determining statistics about the cards and so on, While in the how counts for each expansion mode, each printed expansion has a count of 1 (the Unspecified Expansion entries aren’t counted).
- Show icons for grouping: Controls whether icons are shown with the group name.

#### Card Grouping

By default, Sutekh groups the cards into the separate card types. You can change the grouping as part of the pane profile.

The following groupings are available:

- Clans and Creeds: Group cards by the Clan(s) or Creed(s) listed on the card.The Imbued Creeds are treated as if they were Vampire Clans.
- Disciplines and Virtues: Group cards by the Discipline(s) or Virtue(s) listed on the card. The Imbued Virtues are treated as if they were Vampire Disciplines.
- Disciplines (by level)and Virtues: Group cards by the Discipline(s) or Virtue(s) listed on the card. This distinguishes between inferior and superior levels of the discipline on vampires, but otherwise is the same as the Disciplines and Virtues grouping.
- Crypt or Library: Split the card list into crypt and library cards.
- Card Type: Group by card type. This is the default grouping. This grouping treats multi-type cards, such as Action Modifier/Combat cards as members of both the Action Modifier and the Combat groups.
- Expansion: Group by the expansions in which the cards have been printed.
- Rarity: Group the cards by the published rarity.
- Sect: Group cards by the Sects listed on the card.
- Title: Group cards by the political titles listed on the card.
- Cost: Group cards by the cost of the card.
- Multi Card Type: Behaves like the Card Type grouping, but treats multi-type cards as members of separate types. Thus Action Modifier/Combat will appear as a separate group, and cards of that type will not be listed in the Action Modifier and Combat groups.
- Group: Group the cards by their crypt group.
- Group pairs: Group cards into pairs of adjacent groups. Cards marked as Any Group are considered to belong to all group pairs.
- Artist: Group the cards by their artists.
- Keyword: Group the cards by the keywords associated with them.

#### Extra Columns (card sets)

By default, Sutekh only shows card names in the White Wolf Card List, and card names and card counts in other card set card lists.You can select additional columns to display as part of the pane profile.

The possible extra columns are:

- Clans and Creeds: Show the Clans or Creeds listed on the card.
- Group: Show the group number for the card.
- Disciplines and Virtues: Show the Disciplines or Virtues listed on the card.
- Card Type: Show the card type.
- Expansions: Show the expansions in which the card has been printed.
- Capacity or Life: Show the capacity associated with the card, or its life.
- Sect: Show the Sect associated with the card.
- Title: Show the political titles listed on the card, if it is a crypt card.Titles listed on library cards will not be shown.
- Card Text: Show the text printed on the card.
- Cost: Show the cost of the card, together with the cost type.

You can sort the display by a particular column by clicking on the column header. Click on the same header repeatedly to toggle between ascending and descending order.

Cards which have equal values within the column selected for sorting are further sorted by the card name. Because the different cost types aren’t comparable, if you choose to sort by cost, cards will be grouped by cost type first and sorted within those types.

If you have downloaded the icons from the White Wolf site, you will be able to toggle the display between the Show Icons and Names, Show Text only and Show Icons only options using the combo box. This setting will affect all selected columns that can use icons.

### Card Set Profile Options

You can set the following options or a card set or frame profile:

- Cards To Show: Set which cards are displayed. The options are:
  - This Set Only: Show only the cards in this card set.
  - Show All Cards: Show all the cards in the White Wolf list. Cards not in this card set will have a count of 0.
  - Show all cards in parent card set: Show all the cards in this card set, as well as any cards in the parent card set that are not in this card set.
  - Show all cards in child card sets: Show all the cards in this card set, as well as any cards in those child card sets marked as In Use that are not in this card set.
- Column mode: This controls how information in the extra columns is displayed. You can choose to only show test, only show icons (if applicable) or to show both.
- Extra columns: Select which extra columns of data are shown. See the Extra Columns section for more details.
- Extra levels: Specify what additional information is displayed below the card names in the tree. The options are:
  - Show No Children: Display nothing below the card name.
  - Show Expansions: Show the expansions of the cards, and a card count for each expansion.
  - Show Child Card Sets: Show the card counts for child card sets marked as In Use.
  - Show Expansions and Child Card Sets: Show expansions, and within each expansion show counts for child card sets marked as In Use.
  - Show Child Card Sets and Expansions: Show child card sets marked as In Use, and for each child card set show expansion counts.
- Group by: Controls how the cards are grouped together. See the Card Grouping section for more details.
- Hide cards not legal for tournament play: Controls whether cards flagged as not legal for tournament play (i.e. banned or storyline only cards) are shown in the list.
- Show icons for grouping: Controls whether icons are shown with the group name.
- Parent Count Mode: Specify how the Parent count column is displayed in card sets with a parent set. The options are:
  - Ignore Parent: Hide the parent count column.
  - Parent count: Show only the parent count. If the count for this card set exceeds the parent count, this number is shown in red.
  - Parent Minus this set: Show the difference between the parent count and this card set’s count. If this number is negative, it is shown in red.
  - Parent Minus Sets in Use: Show the difference between the parent count and the total count in all the card sets marked as In Use. If this number is negative, it is shown in red.
- Show icons for the grouping: Toggle whether icons are shown for the top level grouping (when available).

#### The Different Profiles

The display of a cardset is deteremined by 3 different profiles. These are the “local profile”, the “pane profile” and the “card set profile”. Any options that aren’t set by one of these profiles is taken from the Default profile.

The cardset profile is used for any copy of the given card set, when it is first opened. If multiple copies of a card set are open, they all use the same cardset profile, and changing this will effect all open copies of the card set.

The pane profile is used to override settings in the cardset profile and save them across sessions. Pane profile settings are lost when the specific pane is specifically closed, but, as long as the pane is kept open, they are saved and restored as needed.

The local profile is used to set temporary options on the specific pane which override the other profiles. These setting are temporary, and are never saved.

### CardSet List Profile Options

The following options can be set for the card set list profile

- Extra columns: Select which extra columns of data are shown. See the Extra Columns section for more details.

#### Extra Columns (card set list)

Only card set names are shown in the card set list by default as well.You can select additional columns to display as part of the card set list profile.

The possible extra columns are:

- Author: Show the card set author.
- Description: Show the card set description.
- Total cards: Show the total number of cards in the card set.
- Crypt: Show the number of crypt cards in the card set.
- Library: Show the number of library cards in the card set.
- All Children: Show the number of child card sets each card set has
- In-Use Children: Show the number of child card sets marked as in use.

The display can be sorted on these columns by clicking on the column headers.